@@ -6,10 +6,10 @@ from fast_sql.fastsql.sql import to_csv as to_CSV
 from fast_sql.fastsql.sql import Read_sql
 os.environ['NLS_LANG'] = 'SIMPLIFIED CHINESE_CHINA.UTF8'
 
-version = '1.2.12'
+version = '1.2.18'
 
 def read_sql(sql, con, thread_num=15, encoding='utf8', show_progress=False,
-             index_col=None, coerce_float=True, params=None,chunsize=15000,
+             index_col=None, coerce_float=True, params=None,chunksize=15000,
              parse_dates=None, columns=None,
              ):
     """
@@ -81,7 +81,7 @@ def read_sql(sql, con, thread_num=15, encoding='utf8', show_progress=False,
         con,
         thread_num=thread_num,
         encoding=encoding,
-        show_progress=show_progress,chunsize=chunsize)
+        show_progress=show_progress,chunksize=chunksize)
 
     return Fastsql_builder.read_sql(
         index_col=index_col, coerce_float=coerce_float, params=params,
@@ -229,13 +229,16 @@ def to_sql(
         encoding='utf8',
         show_progress=True,
         to_columns=None,
+        chunksize=20000,
         save_path=None,
         index_col=None,
         coerce_float=True,
         params=None,
         parse_dates=None,
         columns=None,
-        delete_cache=False):
+        delete_cache=False,
+        data_processing=None,
+        **kwargs):
     """
     Read SQL query or database table into a DataFrame.
 
@@ -318,7 +321,6 @@ def to_sql(
     assert isinstance(
         thread_num, int), TYPE_Exception(
         'thread_num', value='int')
-    assert isinstance(sql, str), TYPE_Exception('sql', value='str')
     assert isinstance(
         show_progress, bool), TYPE_Exception(
         'show_progress', value='bool')
@@ -340,6 +342,8 @@ def to_sql(
             'mode ERROR: ', value='if mode == w or W ,The file_path must exist')
         assert os.path.exists(file_path), FILEPATH_Exceptions(
             'FileNotFoundError', file_path)
+    if mode.lower() in ['wr','rw','r']:
+        assert isinstance(sql, str), TYPE_Exception('sql', value='str')
 
     Fastsql_builder = to_SQL(
         sql,
@@ -351,11 +355,14 @@ def to_sql(
         thread_num=thread_num,
         encoding=encoding,
         mode=mode,
+        chunksize=chunksize,
         delete_cache=delete_cache,
         show_progress=show_progress,
         file_path=file_path,
         save_path=save_path,
-        thread_w=thread_w)
+        thread_w=thread_w,
+        data_processing= data_processing,
+        **kwargs)
 
     return Fastsql_builder.rsync_db(
         index_col=index_col, coerce_float=coerce_float, params=params,
